/*****************************************************************************
* Copyright (c) Future Technology Devices International 2014
* propriety of Future Technology devices International.
*
* Software License Agreement
*
* This code is provided as an example only and is not guaranteed by FTDI. 
* FTDI accept no responsibility for any issues resulting from its use. 
* The developer of the final application incorporating any parts of this 
* sample project is responsible for ensuring its safe and correct operation 
* and for any consequences resulting from its use.
*****************************************************************************/
/**
* @file                           Sender_Enhanced_SW_Flow_Ctl.ino
* @brief                          Sketch to demonstrate enhanced software flow control functionality for VI800A-232U add-on module.
								  Tested platform version: Arduino 1.0.4 and later
* @version                        1.0.0
* @date                           2014/10/01
*
*/


/* Arduino standard includes */
#include "SPI.h"
#include "Wire.h"


#include "FT_VI800A_232U.h"

FT_VI800A VI800A;


void setup()
{
	/* Initialize serial print related functionality */
	Serial.begin(9600);
    Serial.println("\n\r\n\r-----------Sender_Enhanced_SW_Flow_Ctl.ino--------------");
	
	VI800A.Init(FT_232U_CS);
		
	//the receiver will compare xon1 and xon2 for resume data transmission, and use xoff1 and xoff2 for halt data transmission. number zero as the xon special character and number one as the xoff special character.  The receiver uses no FIFO trigger levels. 	
	VI800A.SetFlowControl(FT_VI800A_SW_Flow,FT_VI800A_NO_TX_FLOW_RX_XON1_XON2_XOFF1_XOFF2,48,48,49,49, FT_VI800A_Use_No_RX_Trigger);
	
	//Enable FIFO, FIFO is enabled implicitly if FIFO trigger levels are specified
	VI800A.EnableFIFO(FT_VI800A_Enable);
	VI800A.clearFIFO();

}

char value[] = {'A','B','C','D','E','F','G','H','I','J','K','L','M','N','O','P','Q','R','S','T','U','V','W','X','Y','Z'};
uint8_t valueIndex=0;
uint8_t command, manualStart=0,incomingData;



void loop()
{
   if(Serial.available() > 0)
   {
		command = Serial.read();
		if(command == 'p')
		{
			manualStart = 1;
			Serial.println("Start to send data.");
		}
   }
   
   //check to see if there is data in the receive FIFO.
   if(VI800A.isDataInReceiver()){
			incomingData = VI800A.Read();
			Serial.print("Received Data: ");
			Serial.println((char)incomingData);
   }
	
	//Send data to the receiver if there is enough room in the transmit FIFO.
	if((VI800A.GetTransmitFIFOFreeSpace()) && manualStart){
		VI800A.Write(value[valueIndex]);
		valueIndex=(valueIndex+1)%26;
	}

	
}


































